#-
#define TYPE "g14"
#define SIZE "8"
*#define ALTERNATEMETHOD "1"
*
*	Test program for the color traces in the paper and a few more.
*	The paper: "Color traces for arbitrary groups"
*	by T. van Ritbergen, A.N. Schellekens and J.A.M. Vermaseren.
*
*	The object is to express color traces in terms of group invariants
*	in such a way that the group has not been specified yet. The few
*	remaining invariants can be substituted afterwards. The expressions
*	in terms of invariants are better for publications. One sees more
*	about the structure of the problem this way.
*
*	All declarations are made in the file cfactors.h
*	One needs version 3 or later of FORM to run these programs.
*	The programs will handle all color structures with up to 14 vertices.
*	One vertex is one generator in any representation.
*	Currently the program handles only one type of non-adjoint representaion.
*	If there are two different representations of such type one has to
*	try to run the problem in stages.
*
*	Examples are:
*	One quark-loop with SIZE gluons in a maximally non-planar configuration
*		(TYPE = qloop)
*	Same but qluon loop (everything in the adjoint representation)
*		(TYPE = gloop)
*	Two quark loops with SIZE connecting gluons like a circular ladder.
*		(TYPE = qqloop)
*	Same with one quark loop and one gluon loop.
*		(TYPE = qgloop)
*	Same with two gluon loops.
*		(TYPE = ggloop)
*	The Coxeter graph (diagram with 14 vertices in the adjoint representation
*	in which there are no loops with fewer than 6 lines) (TYPE = g14)
*
*	One should not choose SIZE larger than 7 or most likely the simplification
*	routine cannot simplify the final result completely (in some rare cases
*	it can though for SIZE = 8).
*	For execution times, see the paper.
*	It does get very slow for quarks and SIZE > 7.
*
*	Program by J.Vermaseren, 24-may-1997
*
#include color.h
AutoDeclare Index i,j,k;
CFunction acc;
Symbol x;
.global
#switch `TYPE'
#case qloop
G	Q{2*`SIZE'} = <T(i1,i2,j1)>*...*<T(i`SIZE',i{`SIZE'+1},j`SIZE')>
	*<T(i{`SIZE'+1},i{`SIZE'+2},j1)>*...*<T(i{`SIZE'*2},i{2*`SIZE'+1},j`SIZE')>
	*replace_(i{`SIZE'*2+1},i1);
Sum i1,...,i{`SIZE'*2},j1,...,j`SIZE';
#break
#case gloop
G	G{2*`SIZE'} = <f(i1,i2,j1)>*...*<f(i`SIZE',i{`SIZE'+1},j`SIZE')>
	*<f(i{`SIZE'+1},i{`SIZE'+2},j1)>*...*<f(i{`SIZE'*2},i{2*`SIZE'+1},j`SIZE')>
	*replace_(i{`SIZE'*2+1},i1);
Sum i1,...,i{`SIZE'*2},j1,...,j`SIZE';
#break
#case qqloop
G	QQ`SIZE' = <T(i1,i2,j1)>*...*<T(i`SIZE',i{`SIZE'+1},j`SIZE')>
	*<T(k1,k2,j1)>*...*<T(k`SIZE',k{`SIZE'+1},j`SIZE')>
	*replace_(i{`SIZE'+1},i1,k{`SIZE'+1},k1);
Sum i1,...,i`SIZE',j1,...,j`SIZE',k1,...,k`SIZE';
#break
#case qgloop
G	QG`SIZE' = <T(i1,i2,j1)>*...*<T(i`SIZE',i{`SIZE'+1},j`SIZE')>
	*<f(k1,k2,j1)>*...*<f(k`SIZE',k{`SIZE'+1},j`SIZE')>
	*replace_(i{`SIZE'+1},i1,k{`SIZE'+1},k1);
Sum i1,...,i`SIZE',j1,...,j`SIZE',k1,...,k`SIZE';
#break
#case ggloop
G	GG`SIZE' = <f(i1,i2,j1)>*...*<f(i`SIZE',i{`SIZE'+1},j`SIZE')>
	*<f(k1,k2,j1)>*...*<f(k`SIZE',k{`SIZE'+1},j`SIZE')>
	*replace_(i{`SIZE'+1},i1,k{`SIZE'+1},k1);
Sum i1,...,i`SIZE',j1,...,j`SIZE',k1,...,k`SIZE';
#break
#case g14
G	girth14 =
		f(i1,i2,i3)*f(i1,i4,i5)*f(i2,i6,i7)*f(i3,i8,i9)
		*f(i4,i10,i11)*f(i5,i12,i13)*f(i6,i14,i15)*f(i7,i16,i17)
		*f(i8,i18,i19)*f(i9,i20,i21)
		*f(i10,i21,i15)*f(i13,i19,i14)*f(i17,i11,i18)*f(i12,i16,i20);
sum i1,...,i21;
#break
#case g24
G	girth24 =
	f(i36,i1,i2)*f(i36,i3,i4)*f(i1,i5,i6)*f(i2,i7,i8)
	*f(i3,i9,i10)*f(i4,i11,i12)*f(i5,i13,i14)*f(i6,i15,i16)
	*f(i7,i17,i18)*f(i8,i19,i20)*f(i9,i21,i22)*f(i10,i23,i24)
	*f(i11,i25,i26)*f(i12,i27,i28)*f(i13,i23,i29)*f(i14,i27,i30)
	*f(i15,i25,i31)*f(i16,i21,i32)*f(i17,i26,i29)*f(i18,i32,i33)
	*f(i19,i31,i34)*f(i20,i22,i30)*f(i24,i34,i35)*f(i28,i33,i35);
sum i1,...,i36;
#break
#case fiveq
G	fiveq = T(i1,i2,j1)*T(i2,i3,j2)*T(i3,i1,j3)*
		 T(i4,i5,j2)*T(i5,i6,j4)*T(i6,i4,j5)*
		 T(i7,i8,j4)*T(i8,i9,j6)*T(i9,i7,j7)*
		 T(i10,i11,j6)*T(i11,i12,j1)*T(i12,i10,j8)*
		 T(i13,i14,j3)*T(i14,i15,j5)*T(i15,i16,j7)*T(i16,i13,j8);
sum i1,...,i16,j1,...,j8;
#break
#endswitch
.sort
#call color
#call SORT(tloop-1)
#call adjoint
Print +f +s;
#call SORT(tloop-2)
Print +f +s;
.sort
#call simpli
id	acc(x?) = x;
Print +f +s;
.end

.store
save tloop.sav;
L  FF = QG8;
#call simpli
id	acc(x?) = x;
Print +f +s;
.end

